==> core-android-debug-1.23.0-sources.jar: commonMain/io/dyte/core/feat/DyteChatMessage.kt <==
package io.dyte.core.feat

import io.dyte.core.feat.DyteMessageType.FILE
import io.dyte.core.feat.DyteMessageType.IMAGE
import io.dyte.core.feat.DyteMessageType.TEXT

open class DyteChatMessage(
  val userId: String,
  val displayName: String,
  val read: Boolean,
  val pluginId: String?,
  val type: DyteMessageType,
  val time: String
)

class DyteTextMessage(
  userId: String,
  displayName: String,
  read: Boolean,
  pluginId: String?,
  val message: String,
  time: String
) : DyteChatMessage(userId, displayName, read, pluginId, TEXT, time)

class DyteImageMessage(
  userId: String,
  displayName: String,
  read: Boolean,
  pluginId: String?,
  val link: String,
  time: String
) : DyteChatMessage(userId, displayName, read, pluginId, IMAGE, time)

class DyteFileMessage(
  userId: String,
  displayName: String,
  read: Boolean,
  pluginId: String?,
  val name: String,
  time: String,
  val link: String,
  val size: Long
) : DyteChatMessage(userId, displayName, read, pluginId, FILE, time)

fun encodeDyteChatMessage(message: DyteChatMessage): Map<String, Any?> {
  val chatMessageMap = HashMap<String, Any?>()
  chatMessageMap["displayName"] = message.displayName
  chatMessageMap["type"] = message.type.name
  chatMessageMap["read"] = message.read
  chatMessageMap["user"] = message.userId
  chatMessageMap["pluginId"] = message.pluginId
  chatMessageMap["time"] = message.time
  when (message) {
    is DyteFileMessage -> {
      chatMessageMap["name"] = message.name
      chatMessageMap["link"] = message.link
      chatMessageMap["size"] = message.size
    }
    is DyteTextMessage -> {
      chatMessageMap["message"] = message.message
    }
    is DyteImageMessage -> {
      chatMessageMap["link"] = message.link
    }
  }
  return chatMessageMap
}

enum class DyteMessageType {
  TEXT,
  IMAGE,
  FILE
}

==> core-android-debug-1.30.2-sources.jar: commonMain/io/dyte/core/feat/DyteChatMessage.kt <==
package io.dyte.core.feat

import io.dyte.core.feat.DyteMessageType.FILE
import io.dyte.core.feat.DyteMessageType.IMAGE
import io.dyte.core.feat.DyteMessageType.TEXT

open class DyteChatMessage(
  val userId: String,
  val displayName: String,
  val read: Boolean,
  val pluginId: String?,
  val type: DyteMessageType,
  val time: String,
  val channelId: String?
)

class DyteTextMessage(
  userId: String,
  displayName: String,
  read: Boolean,
  pluginId: String?,
  val message: String,
  time: String,
  channelId: String? = null
) : DyteChatMessage(userId, displayName, read, pluginId, TEXT, time, channelId)

class DyteImageMessage(
  userId: String,
  displayName: String,
  read: Boolean,
  pluginId: String?,
  val link: String,
  time: String,
  channelId: String? = null
) : DyteChatMessage(userId, displayName, read, pluginId, IMAGE, time, channelId)

class DyteFileMessage(
  userId: String,
  displayName: String,
  read: Boolean,
  pluginId: String?,
  val name: String,
  time: String,
  val link: String,
  val size: Long,
  channelId: String? = null
) : DyteChatMessage(userId, displayName, read, pluginId, FILE, time, channelId)

fun encodeDyteChatMessage(message: DyteChatMessage): Map<String, Any?> {
  val chatMessageMap = HashMap<String, Any?>()
  chatMessageMap["displayName"] = message.displayName
  chatMessageMap["type"] = message.type.name
  chatMessageMap["read"] = message.read
  chatMessageMap["user"] = message.userId
  chatMessageMap["pluginId"] = message.pluginId
  chatMessageMap["time"] = message.time
  chatMessageMap["channelId"] = message.channelId
  when (message) {
    is DyteFileMessage -> {
      chatMessageMap["name"] = message.name
      chatMessageMap["link"] = message.link
      chatMessageMap["size"] = message.size
    }
    is DyteTextMessage -> {
      chatMessageMap["message"] = message.message
    }
    is DyteImageMessage -> {
      chatMessageMap["link"] = message.link
    }
  }
  return chatMessageMap
}

enum class DyteMessageType {
  TEXT,
  IMAGE,
  FILE
}
